@@ -19,7 +19,7 @@ import email
 import email.parser
 import email.message
 import email.utils
-import emailclients
+import unforward.emailclients
 import quopri
 from unforward.errors import NoForwardFoundError
 
@@ -28,7 +28,7 @@ class Extractor:
     def __init__(self):
         self.parser = email.parser.Parser()
         # Grab the list of clients from the emailclients module
-        self.clients = [client() for client in emailclients.clients]
+        self.clients = [client() for client in unforward.emailclients.clients]
     
     def get_client(self, name):
         for client in self.clients:
