@@ -32,7 +32,7 @@ def main():
         email_text = ''.join(line for line in fileinput.input())
         result = extractor.extract(email_text)
     
-    print json.dumps(result)
+    print(json.dumps(result))
     
 
 
