@@ -18,7 +18,7 @@
 import unittest
 import unforward
 from unforward.errors import ExtractionError
-from examples import examples
+from unforward.test.examples import examples
 
 class ExtractorTest(unittest.TestCase):
     """ This test-case tests the general purpose extractor, including its ability to decide which
@@ -34,16 +34,18 @@ class ExtractorTest(unittest.TestCase):
     
     def test_automatch(self):
         for example in self.examples:
-            html = ''.join(open(unforward.get_data(example['file'])))
-            client = self.extractor.get_client(example['client'][0])
-            # Only consider clients that are implemented.
-            if client.implemented:
-                result = self.extractor.extract_from_html(html)
-                self.assertEqual(result, example['result'])
+            with open(unforward.get_data(example['file'])) as f:
+                html = ''.join(f.readlines())
+                client = self.extractor.get_client(example['client'][0])
+                # Only consider clients that are implemented.
+                if client.implemented:
+                    result = self.extractor.extract_from_html(html)
+                    self.assertEqual(result, example['result'])
     
     def test_mime(self):
-        mimetext = ''.join(open(unforward.get_data("examples/gmail_forward_2.mime")))
-        result = self.extractor.extract(mimetext)
-        expected = {'body': '<div><div><div>Comodo,<br/>\n<br/></div>I have to say that I am impressed by your thoroughness on our company background check. 5 stars for actually doing a background check.<br/><br/></div>Our accountant Tara is registered under the Chartered Professional Accountants of Ontario.<br/>\n<br/></div>Brad<br/>', 'sender': u'brad@getsensibill.com'}
-        self.assertEqual(result, expected)
+        with open(unforward.get_data("examples/gmail_forward_2.mime")) as f:
+            mimetext = ''.join(f.readlines())
+            result = self.extractor.extract(mimetext)
+            expected = {'body': '<div><div><div>Comodo,<br/>\n<br/></div>I have to say that I am impressed by your thoroughness on our company background check. 5 stars for actually doing a background check.<br/><br/></div>Our accountant Tara is registered under the Chartered Professional Accountants of Ontario.<br/>\n<br/></div>Brad<br/>', 'sender': u'brad@getsensibill.com'}
+            self.assertEqual(result, expected)
         
